summaryrefslogtreecommitdiff
path: root/sc
diff options
context:
space:
mode:
authorXisco Fauli <xiscofauli@libreoffice.org>2022-01-20 11:54:16 +0100
committerXisco Fauli <xiscofauli@libreoffice.org>2022-01-20 13:38:18 +0100
commit5c3ae3024891341c8bcf77ad6b22c2a8c74585c5 (patch)
tree8f349064f0a4089d7c5e73c7073068e46d8f7c95 /sc
parent02140554ee1d70b219a42546191e2219d58be4b0 (diff)
uitest: sc: make sure text is copied from the input window
Change-Id: I17f163486f253bc80f40f13c01fb61187d8276e4 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/128649 Tested-by: Jenkins Reviewed-by: Xisco Fauli <xiscofauli@libreoffice.org>
Diffstat (limited to 'sc')
-rw-r--r--sc/qa/uitest/inputLine/tdf67346.py21
1 files changed, 12 insertions, 9 deletions
diff --git a/sc/qa/uitest/inputLine/tdf67346.py b/sc/qa/uitest/inputLine/tdf67346.py
index 3870a3093d39..5d5ff32cefb5 100644
--- a/sc/qa/uitest/inputLine/tdf67346.py
+++ b/sc/qa/uitest/inputLine/tdf67346.py
@@ -8,13 +8,10 @@
#
from uitest.framework import UITestCase
from uitest.uihelper.common import get_state_as_dict
-from uitest.uihelper.common import select_pos
from uitest.uihelper.calc import enter_text_to_cell
-from libreoffice.calc.document import get_sheet_from_doc
-from libreoffice.calc.conditional_format import get_conditional_format_from_sheet
-from uitest.debug import sleep
from libreoffice.calc.document import get_cell_by_position
from libreoffice.uno.propertyvalue import mkPropertyValues
+
#Bug 67346 - EDITING: Undo broken when pasting text that has been copied from the input line
class tdf67346(UITestCase):
@@ -23,19 +20,25 @@ class tdf67346(UITestCase):
with self.ui_test.create_doc_in_start_center("calc") as document:
xCalcDoc = self.xUITest.getTopFocusWindow()
gridwin = xCalcDoc.getChild("grid_window")
- # type 'Apple' in A1
+
enter_text_to_cell(gridwin, "A1", "Apple")
- # input line: copy the text from there
+
+ # Move focus to input window and copy the text from there
+ gridwin.executeAction("TYPE", mkPropertyValues({"KEYCODE":"CTRL+SHIFT+F2"}))
+
xInputWin = xCalcDoc.getChild("sc_input_window")
- xInputWin.executeAction("TYPE", mkPropertyValues({"KEYCODE":"CTRL+A"}))
+ self.assertEqual('true', get_state_as_dict(xInputWin)["HasFocus"])
+
+ self.xUITest.executeCommand(".uno:SelectAll")
self.xUITest.executeCommand(".uno:Copy")
+
gridwin.executeAction("SELECT", mkPropertyValues({"CELL": "A2"}))
- # Ctrl-V
+
self.xUITest.executeCommand(".uno:Paste")
self.assertEqual(get_cell_by_position(document, 0, 0, 0).getString(), "Apple")
self.assertEqual(get_cell_by_position(document, 0, 0, 1).getString(), "Apple")
self.assertEqual(get_state_as_dict(xInputWin)["Text"], "Apple")
- #Ctrl-Z
+
self.xUITest.executeCommand(".uno:Undo")
self.assertEqual(get_cell_by_position(document, 0, 0, 0).getString(), "Apple")
self.assertEqual(get_cell_by_position(document, 0, 0, 1).getString(), "")